pub enum PersistenceType {
Lapse,
Persist,
MarketOnClose,
}Expand description
How unmatched bets are handled at market turn in-play.
Variants
Lapse
Bet is lapsed (cancelled) when market turns in-play.
Persist
Bet persists when market turns in-play.
MarketOnClose
Bet is placed as a Market On Close order.